#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = __importStar(require("path"));
const chokidar = __importStar(require("chokidar"));
const glob_1 = __importDefault(require("glob"));
const yargs = __importStar(require("yargs"));
const chalk_1 = __importDefault(require("chalk"));
const dts_creator_1 = require("./dts-creator");
const yarg = yargs.usage('Create .css.d.ts from CSS modules *.css files.\nUsage: $0 [options] <input directory>')
    .example('$0 src/styles', '')
    .example('$0 src -o dist', '')
    .example('$0 -p styles/**/*.icss -w', '')
    .detectLocale(false)
    .demand(['_'])
    .alias('c', 'camelCase').describe('c', 'Convert CSS class tokens to camelcase')
    .alias('o', 'outDir').describe('o', 'Output directory')
    .alias('p', 'pattern').describe('p', 'Glob pattern with css files')
    .alias('w', 'watch').describe('w', 'Watch input directory\'s css files or pattern').boolean('w')
    .alias('d', 'dropExtension').describe('d', 'Drop the input files extension').boolean('d')
    .alias('s', 'silent').describe('s', 'Silent output. Do not show "files written" messages').boolean('s')
    .alias('h', 'help').help('h')
    .version(() => require('../package.json').version);
const argv = yarg.argv;
let creator;
function writeFile(f) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const content = yield creator.create(f, undefined, !!argv.w);
            yield content.writeFile();
            if (!argv.s) {
                console.log('Wrote ' + chalk_1.default.green(content.outputFilePath));
            }
        }
        catch (error) {
            console.error(chalk_1.default.red('[Error] ' + error));
        }
    });
}
;
function main() {
    let rootDir;
    let searchDir;
    if (argv.h) {
        yarg.showHelp();
        return;
    }
    if (argv._ && argv._[0]) {
        searchDir = argv._[0];
    }
    else if (argv.p) {
        searchDir = './';
    }
    else {
        yarg.showHelp();
        return;
    }
    const filesPattern = path.join(searchDir, argv.p || '**/*.css');
    rootDir = process.cwd();
    creator = new dts_creator_1.DtsCreator({
        rootDir,
        searchDir,
        outDir: argv.o,
        camelCase: argv.c,
        dropExtension: argv.d
    });
    if (!argv.w) {
        glob_1.default(filesPattern, {}, (err, files) => {
            if (err) {
                console.error(err);
                return;
            }
            if (!files || !files.length)
                return;
            files.forEach(writeFile);
        });
    }
    else {
        console.log('Watch ' + filesPattern + '...');
        const watcher = chokidar.watch([filesPattern.replace(/\\/g, "/")]);
        watcher.on('add', writeFile);
        watcher.on('change', writeFile);
    }
}
;
main();
